export const messageNoLayout = (e, type) => {
  const messagesWrapper = document.querySelector('[data-drupal-messages]');
  if (messagesWrapper && messagesWrapper.innerHTML === '\n') {
    messagesWrapper.innerHTML = '';
  }

  const messages = new Drupal.Message();
  const messageId = messages.add('No layout loaded.', { type: 'error' });
  setTimeout(() => {
    messages.remove(messageId);
  }, 2000);
};

/**
 * Update place block sidebar.
 *
 * The blocks listed in the place block sidebar can differ based on the entity
 * being edited e.g. when switching from editing the main entity to a nested
 * layout block.
 *
 * @returns {Promise<unknown>}
 */
export const updatePlaceBlockSidebar = () => {
  return new Promise((resolve, reject) => {
    const editMode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
    const wrapper = editMode.getMainEntityWrapper();
    if (!wrapper) {
      return;
    }
    const parts = wrapper.dataset.navigationPlusEntityWrapper.split('::');

    let ajax = Drupal.NavigationPlus.ModePluginBase.ajax({
      url: Drupal.url('lb-plus/load-place-block-sidebar/overrides/' + parts[0] + '.' + parts[1]),
      type: 'POST',
      dataType: 'text',
      progress: {
        type: 'fullscreen',
        message: Drupal.t('Loading Place Block Sidebar...'),
      },
      error: error => {
        document.querySelectorAll('.ajax-progress').forEach(progress => {
          progress.remove();
        });
        messageNoLayout();
        console.info('Attempted to load Place Block Sidebar for ' + wrapper.dataset.navigationPlusEntityWrapper);
        console.info(error.responseText);
      },
      success: (response, status) => {
        Promise.resolve(
          Drupal.Ajax.prototype.success.call(ajax, response, status),
        ).then(() => {
          Drupal.displace(true);
          resolve();
        }).catch((e) => {
          reject(e.responseText);
        });
      },
    });
    ajax.execute();
  });
};

